@@ -260,8 +260,8 @@ int __stdcall FillRF64Header(RF64_HEADER * pWAVHeader, APE::int64 nAudioBytes, c
 
 int __stdcall GetAPEFileType(const APE::str_utfn * pInputFilename, APE::str_ansi cFileType[8])
 {
-    memset(&cFileType[0], 0, sizeof(cFileType[0]) * 8);
-
+    APE_CLEAR_ARRAY(cFileType, 8);
+    
     int nErrorCode = 0;
     CAPEInfo Info(&nErrorCode, pInputFilename, APE_NULL, false, true, false);
 
