@@ -235,7 +235,6 @@ CWAVInputSource::CWAVInputSource(IAPEIO * pIO, WAVEFORMATEX * pwfeSource, int64
     m_nFileBytes = 0;
     m_nHeaderBytes = 0;
     m_bFloat = false; // we need a boolean instead of just checking WAVE_FORMAT_IEEE_FLOAT since it can be extensible with the format float
-    APE_CLEAR(m_wfeSource);
     m_bUnknownLengthFile = false;
     m_pTag = pTag;
 
@@ -255,7 +254,7 @@ CWAVInputSource::CWAVInputSource(IAPEIO * pIO, WAVEFORMATEX * pwfeSource, int64
 
     // analyze source
     int nResult = AnalyzeSource();
-    if (nResult == ERROR_SUCCESS)
+    if ((nResult == ERROR_SUCCESS) && (m_wfeSource.nBlockAlign > 0))
     {
         // fill in the parameters
         if (pwfeSource) memcpy(pwfeSource, &m_wfeSource, sizeof(WAVEFORMATEX));
@@ -331,7 +330,7 @@ int CWAVInputSource::AnalyzeSource()
         }
 
         // we need to read the chunk so CBufferIO objects keep working nicely (seeking is tricky for them)
-        CSmartPtr<unsigned char> spExtraChunk(new unsigned char [RIFFChunkHeader.nChunkBytes], true);
+        CSmartPtr<unsigned char> spExtraChunk(RIFFChunkHeader.nChunkBytes);
         RETURN_ON_ERROR(ReadSafe(m_spIO, spExtraChunk, static_cast<int>(RIFFChunkHeader.nChunkBytes)))
 
         // check again for the data chunk
@@ -383,7 +382,7 @@ int CWAVInputSource::AnalyzeSource()
         else if ((nWAVFormatHeaderExtra > 0) && (nWAVFormatHeaderExtra < APE_BYTES_IN_MEGABYTE))
         {
             // read the extra
-            CSmartPtr<unsigned char> spWAVFormatHeaderExtra(new unsigned char [static_cast<size_t>(nWAVFormatHeaderExtra)], true);
+            CSmartPtr<unsigned char> spWAVFormatHeaderExtra(nWAVFormatHeaderExtra);
             RETURN_ON_ERROR(ReadSafe(m_spIO, spWAVFormatHeaderExtra, static_cast<int>(nWAVFormatHeaderExtra)))
 
             // the extra specifies the format and it might not be PCM, so check
@@ -424,7 +423,7 @@ int CWAVInputSource::AnalyzeSource()
                 }
                 else
                 {
-                    // size is undefined so don't look at it
+                    // size is not the size we understand so don't look at it
                 }
             }
         }
@@ -486,7 +485,7 @@ int CWAVInputSource::AnalyzeSource()
         {
             // read the tag
             int nTagBytes = static_cast<int>(RIFFChunkHeader.nChunkBytes);
-            CSmartPtr<unsigned char> spTag(new unsigned char [static_cast<size_t>(nTagBytes)], true);
+            CSmartPtr<unsigned char> spTag(nTagBytes);
             RETURN_ON_ERROR(ReadSafe(m_spIO, spTag, nTagBytes))
 
             // analyze the tag data
@@ -656,7 +655,6 @@ CAIFFInputSource::CAIFFInputSource(IAPEIO * pIO, WAVEFORMATEX * pwfeSource, int6
     m_bLittleEndian = false;
     m_bFloat = false;
     m_pTag = pTag;
-    APE_CLEAR(m_wfeSource);
 
     if (pIO == APE_NULL || pwfeSource == APE_NULL)
     {
@@ -667,7 +665,7 @@ CAIFFInputSource::CAIFFInputSource(IAPEIO * pIO, WAVEFORMATEX * pwfeSource, int6
     m_spIO.Assign(pIO);
 
     int nResult = AnalyzeSource();
-    if (nResult == ERROR_SUCCESS)
+    if ((nResult == ERROR_SUCCESS) && (m_wfeSource.nBlockAlign > 0))
     {
         // fill in the parameters
         if (pwfeSource) memcpy(pwfeSource, &m_wfeSource, sizeof(WAVEFORMATEX));
@@ -690,19 +688,19 @@ int CAIFFInputSource::AnalyzeSource()
     // analyze AIFF header
     //
     // header has 54 bytes
-    //    FORM                        - 4 bytes        "FORM"
-    //      Size                        - 4                size of all data, excluding the top 8 bytes
-    //      AIFF                        - 4                "AIFF"
-    //        COMM                    - 4                "COMM"
-    //          size                    - 4                size of COMM chunk excluding the 8 bytes for "COMM" and size, should be 18
-    //            Channels            - 2                number of channels
-    //            sampleFrames        - 4                number of frames
-    //            sampleSize            - 2                size of each sample
-    //            sampleRate            - 10            samples per second
-    //        SSND                    - 4                "SSND"
-    //          size                    - 4                size of all data in the chunk, excluding "SSND" and size field
-    //            BlockAlign            - 4                normally set to 0
-    //            Offset                - 4                normally set to 0
+    //    FORM                        - 4 bytes       "FORM"
+    //      Size                      - 4             size of all data, excluding the top 8 bytes
+    //      AIFF                      - 4             "AIFF"
+    //        COMM                    - 4             "COMM"
+    //          size                  - 4             size of COMM chunk excluding the 8 bytes for "COMM" and size, should be 18
+    //            Channels            - 2             number of channels
+    //            sampleFrames        - 4             number of frames
+    //            sampleSize          - 2             size of each sample
+    //            sampleRate          - 10            samples per second
+    //        SSND                    - 4             "SSND"
+    //          size                  - 4             size of all data in the chunk, excluding "SSND" and size field
+    //            BlockAlign          - 4             normally set to 0
+    //            Offset              - 4             normally set to 0
     //            Audio data follows
 
     // get the file size
@@ -851,7 +849,7 @@ int CAIFFInputSource::AnalyzeSource()
             // tag
             int nTagBytes = static_cast<int>(Chunk.nChunkBytes);
             CSmartPtr<unsigned char> spTag;
-            spTag.Assign(new unsigned char[static_cast<size_t>(nTagBytes)], true);
+            spTag.AllocateArray(nTagBytes);
             RETURN_ON_ERROR(ReadSafe(m_spIO, spTag.GetPtr(), nTagBytes))
 
             bSeekToNextChunk = false;
@@ -981,9 +979,8 @@ CW64InputSource::CW64InputSource(IAPEIO * pIO, WAVEFORMATEX * pwfeSource, int64
     m_nFileBytes = 0;
     m_nHeaderBytes = 0;
     m_nTerminatingBytes = 0;
-    APE_CLEAR(m_wfeSource);
 
-    if (pIO == APE_NULL || pwfeSource == APE_NULL)
+    if ((pIO == APE_NULL) || (pwfeSource == APE_NULL))
     {
         if (pErrorCode) *pErrorCode = ERROR_BAD_PARAMETER;
         return;
@@ -992,7 +989,7 @@ CW64InputSource::CW64InputSource(IAPEIO * pIO, WAVEFORMATEX * pwfeSource, int64
     m_spIO.Assign(pIO);
 
     int nResult = AnalyzeSource();
-    if (nResult == ERROR_SUCCESS)
+    if ((nResult == ERROR_SUCCESS) && (m_wfeSource.nBlockAlign > 0))
     {
         // fill in the parameters
         if (pwfeSource) memcpy(pwfeSource, &m_wfeSource, sizeof(WAVEFORMATEX));
@@ -1207,7 +1204,6 @@ CSNDInputSource::CSNDInputSource(IAPEIO * pIO, WAVEFORMATEX * pwfeSource, int64
     m_nHeaderBytes = 0;
     m_nTerminatingBytes = 0;
     m_bBigEndian = false;
-    APE_CLEAR(m_wfeSource);
 
     if (pIO == APE_NULL || pwfeSource == APE_NULL)
     {
@@ -1218,7 +1214,7 @@ CSNDInputSource::CSNDInputSource(IAPEIO * pIO, WAVEFORMATEX * pwfeSource, int64
     m_spIO.Assign(pIO);
 
     int nResult = AnalyzeSource(pFlags);
-    if (nResult == ERROR_SUCCESS)
+    if ((nResult == ERROR_SUCCESS) && (m_wfeSource.nBlockAlign > 0))
     {
         // fill in the parameters
         if (pwfeSource) memcpy(pwfeSource, &m_wfeSource, sizeof(WAVEFORMATEX));
@@ -1444,7 +1440,6 @@ CCAFInputSource::CCAFInputSource(IAPEIO * pIO, WAVEFORMATEX * pwfeSource, int64
     m_nHeaderBytes = 0;
     m_nTerminatingBytes = 0;
     m_bLittleEndian = false;
-    APE_CLEAR(m_wfeSource);
 
     if (pIO == APE_NULL || pwfeSource == APE_NULL)
     {
@@ -1455,7 +1450,7 @@ CCAFInputSource::CCAFInputSource(IAPEIO * pIO, WAVEFORMATEX * pwfeSource, int64
     m_spIO.Assign(pIO);
 
     int nResult = AnalyzeSource();
-    if (nResult == ERROR_SUCCESS)
+    if ((nResult == ERROR_SUCCESS) && (m_wfeSource.nBlockAlign > 0))
     {
         // fill in the parameters
         if (pwfeSource) memcpy(pwfeSource, &m_wfeSource, sizeof(WAVEFORMATEX));
